<?php

namespace Fazed\NyaaRssParser\Test;

use Fazed\NyaaRssParser\Enums\NyaaFilters;
use Fazed\NyaaRssParser\Enums\NyaaCategories;
use Fazed\NyaaRssParser\Contracts\NyaaRssParserContract;
use Fazed\NyaaRssParser\Contracts\HttpClient\ResponseContract;

class ParserTest extends TestCase
{
    /** @test */
    public function it_can_fetch_feed()
    {
        /** @var NyaaRssParserContract $parser */
        $parser = app(NyaaRssParserContract::class);

        /** @var ResponseContract $response */
        $response = $parser->getRssFeed();

        $this->assertGreaterThan(0, $response->getEntryCount());
    }

    /** @test */
    public function it_can_fetch_feed_with_category()
    {
        /** @var NyaaRssParserContract $parser */
        $parser = app(NyaaRssParserContract::class);

        /** @var ResponseContract $response */
        $response = $parser->getRssFeed(NyaaCategories::ANIME_ENGLISH);

        $this->assertGreaterThan(0, $response->getEntryCount());
    }

    /** @test */
    public function it_can_fetch_feed_with_filter()
    {
        /** @var NyaaRssParserContract $parser */
        $parser = app(NyaaRssParserContract::class);

        /** @var ResponseContract $response */
        $response = $parser->getRssFeed(null, NyaaFilters::TRUSTED_ONLY);

        $this->assertGreaterThan(0, $response->getEntryCount());
    }

    /** @test */
    public function it_can_fetch_feed_with_category_and_filter()
    {
        /** @var NyaaRssParserContract $parser */
        $parser = app(NyaaRssParserContract::class);

        /** @var ResponseContract $response */
        $response = $parser->getRssFeed(
            NyaaCategories::ANIME_ENGLISH,
            NyaaFilters::TRUSTED_ONLY
        );

        $this->assertGreaterThan(0, $response->getEntryCount());
    }
}
